import Logging from "@hibas123/nodelogging";
import Web from "./web";
import config from "./config";
import { DatabaseManager } from "./database/database";
import { createServer } from "http";
import { ConnectionManager } from "./connection";
import { LoggingTypes } from "@hibas123/logging";
import * as pk from "../package.json";

Logging.logLevel = config.dev ? LoggingTypes.Debug : LoggingTypes.Log;

Logging.log("Starting Database version:", pk.version);

DatabaseManager.init().then(() => {
   const http = createServer(Web.callback());
   ConnectionManager.bind(http);
   const port = config.port || 5000;
   http.listen(port, () => Logging.log("Listening on port:", port))
}).catch(err => {
   Logging.error(err);
   process.exit(-1);
})